import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TEXT_DIR = Path.cwd() / "tests" / "text"


class TestEncoding(unittest.TestCase):
    def test_empty(self):
        example_rtf = RTF_DIR / "encoding.rtf"
        example_txt = TEXT_DIR / "encoding.txt"

        with example_rtf.open() as source:
            result = rtf_to_text(source.read(), errors="ignore")
        with example_txt.open() as destination:
            self.assertEqual(destination.read(), result)



import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TEXT_DIR = Path.cwd() / "tests" / "text"


class TestPartialConversion(unittest.TestCase):

    def test_partial(self):
        example_rtf = RTF_DIR / "BVWGT_20241227_W258_2227269_1_00_01.rtf"
        example_txt = TEXT_DIR / "BVWGT_20241227_W258_2227269_1_00_01.txt"

        with example_rtf.open(encoding="ISO-8859-1") as source:
            raw = source.read()
            result = rtf_to_text(raw, errors="ignore")

        with example_txt.open() as destination:
            self.assertEqual(destination.read(), result)

   


import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TXT_DIR = Path.cwd() / "tests" / "text"


class TestSimple(unittest.TestCase):
    """
    Single backlash is not captured therefore the txt is without line breaks.
    """

    def test_extract_simple_table(self):
        simple_table_rtf = RTF_DIR / "line_break_textedit_mac.rtf"
        simple_table_txt = TXT_DIR / "line_break_textedit_mac.txt"

        with simple_table_rtf.open() as source:
            result = rtf_to_text(source.read())
        with simple_table_txt.open() as destination:
            self.assertEqual(destination.read(), result)




from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TEXT_DIR = Path.cwd() / "tests" / "text"


def test_empty():
    example_rtf = RTF_DIR / "issue_15.rtf"
    example_txt = TEXT_DIR / "issue_15.txt"

    with example_rtf.open() as source:
        result = rtf_to_text(source.read(), errors="ignore")
    with example_txt.open(encoding="utf-8") as destination:
        assert destination.read() == result



import unittest

from striprtf.striprtf import rtf_to_text


class TestFromString(unittest.TestCase):
    def test_from_simple_string(self):
        source = (
            "{\\rtf1\\ansi\n{\\fonttbl\\f0\\fnil Monospaced;\\f1\\fnil DejaVu Sans;}\n"
            "{\\colortbl\\red0\\green0\\blue0;\\red0\\green0\\blue0;}\n\n"
            "\\f1\\fs24\\i0\\b0\\cf1 Hello with simple text.\\par\n}\n"
        )
        result = rtf_to_text(source)
        self.assertEqual("Hello with simple text.\n", result)

    def test_with_special_chars_and_encoding_parameter(self):
        source = (
            "{\\rtf1\\ansi\\n{\\fonttbl\\f0\\fnil Monospaced;\\f1\\fnil DejaVu Sans;}\n"
            "{\\colortbl\\red0\\green0\\blue0;\\red0\\green0\\blue0;}\n"
            "\\f1\\fs24\\i0\\b0\\cf1 Visibilit\\'e9 r\\'e9duite sur les montagnes.\\par\\n}"
        )
        result = rtf_to_text(source, encoding="latin-1")
        self.assertEqual("Visibilité réduite sur les montagnes.\n", result)



import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF = r"""{\rtf1\fbidis\ansi\ansicpg1252\deff0\nouicompat\deflang1033{\fonttbl{\f0\fnil\fcharset0 Microsoft Sans Serif;}{\f1\fswiss\fcharset134 Microsoft YaHei;}{\f2\fnil Microsoft Sans Serif;}}
{\*\generator Riched20 10.0.19041}\viewkind4\uc1 
\pard\ltrpar\f0\fs17 
00:00:44:22\par
00:00:48:05\par
\f1\'b8\'f9\'be\'dd\'d5\'e6\'ca\'b5\'b9\'ca\'ca\'c2\'b4\'b4\'d7\'f7\f0\par"""


class Table(unittest.TestCase):
    def test_parse_w_fontbl(self):
        result = rtf_to_text(RTF)
        self.assertEqual("00:00:44:22\n00:00:48:05\n根据真实故事创作\n", result)



import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TEXT_DIR = Path.cwd() / "tests" / "text"


class TestUnicodePolish(unittest.TestCase):
    def test_polish(self):
        example_rtf = RTF_DIR / "ansicpg1250.rtf"
        example_txt = TEXT_DIR / "ansicpg1250.txt"

        with example_rtf.open() as source:
            result = rtf_to_text(source.read())
        with example_txt.open(encoding="utf-8") as destination:
            self.assertEqual(destination.read(), result)



import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TXT_DIR = Path.cwd() / "tests" / "text"


class TestSimple(unittest.TestCase):
    def test_extract_hyperlink(self):
        hyperlink_rtf = RTF_DIR / "hyperlink.rtf"
        hyperlink_txt = TXT_DIR / "hyperlink.txt"

        with hyperlink_rtf.open() as source:
            result = rtf_to_text(source.read())
        with hyperlink_txt.open() as destination:
            self.assertEqual(destination.read(), result)



import unittest

from striprtf.striprtf import rtf_to_text

RTF = r"{\rtf1\ansi\ansicpg0 T\'e4st}"


class Table(unittest.TestCase):
    def test_error_handling_ignore(self):
        result = rtf_to_text(RTF, errors="ignore")
        self.assertEqual("Tst", result)

    def test_error_handling_replace(self):
        result = rtf_to_text(RTF, errors="replace")
        self.assertEqual("T�st", result)



import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TEXT_DIR = Path.cwd() / "tests" / "text"


class TestListtextNumbering(unittest.TestCase):
    """Test that \\listtext numbering is preserved in output.

    See https://github.com/joshy/striprtf/issues/63
    """

    def test_listtext_numbering_preserved(self):
        example_rtf = RTF_DIR / "issue_63.rtf"
        example_txt = TEXT_DIR / "issue_63.txt"

        with example_rtf.open() as source:
            raw = source.read()
            result = rtf_to_text(raw)

        with example_txt.open() as destination:
            self.assertEqual(destination.read(), result)



import unittest
from pathlib import Path

from striprtf.striprtf import rtf_to_text

RTF_DIR = Path.cwd() / "tests" / "rtf"
TEXT_DIR = Path.cwd() / "tests" / "text"


RTF_TABLE = r"""
{\rtf1\ansi\deff0
\trowd
\cellx1000
\cellx2000
\cellx3000
\intbl cell 1\cell
\intbl cell 2\cell
\intbl cell 3\cell
\row
}
"""

TEXT_TABLE = """cell 1|cell 2|cell 3|
"""


class Table(unittest.TestCase):
    def test_table_file(self):
        example_rtf = RTF_DIR / "issue_38.rtf"
        example_txt = TEXT_DIR / "issue_38.txt"

        with example_rtf.open() as source:
            result = rtf_to_text(source.read())
        with example_txt.open() as destination:
            self.assertEqual(destination.read(), result)

    def test_table_string(self):
        result = rtf_to_text(RTF_TABLE)
        self.assertEqual(TEXT_TABLE, result)
